Function for computing the scaled ranks for each column of the input matrix.
In other words, the values are ranked column-wise and divided by
nrow(x) + 1. A "1334" ranking scheme is used where the lowest values
is awarded rank 1, second lowest value rank 2, and ties are given the
maximum available rank.
Usage
Uhat(x)
Value
A matrix with the same dimensions as x of the scaled
ranks.
Arguments
x
A numericmatrix of observations to be ranked. Rows
correspond to features and columns to experiments.
Author
Anders Ellern Bilgrau <anders.ellern.bilgrau@gmail.com>