powered by
The logit transformation (i.e. the log of the odds) and its inverse (also called expit).
inv.logit(a)logit(p)
logit(p)
inv.logit returns a vector of the same length as a of the inverse logit transformed values. This function is also known as the expit-function.
inv.logit
a
logit returns a vector of the same length as p with the log odds of p.
logit
p
A vector of real values.
A vector of probabilities.
Anders Ellern Bilgrau <anders.ellern.bilgrau@gmail.com>
Used in tt and inv.tt.
tt
inv.tt
p <- runif(100) print(a <- GMCM:::logit(p)) p - GMCM:::inv.logit(a)
Run the code above in your browser using DataLab