powered by
Fast simulation from and evaluation of multivariate Gaussian probability densities.
dmvnormal(x, mu, sigma)rmvnormal(n, mu, sigma)
rmvnormal(n, mu, sigma)
dmvnormal returns a \(1\) by \(p\) matrix of the probability densities corresponding to each row of x. sigma. Each row corresponds to an observation.
dmvnormal
x
sigma
rmvnormal returns a p by k matrix of observations from a multivariate normal distribution with the given mean
rmvnormal
p
k
mu and covariance
mu
A p times k matrix of quantiles. Each rows correspond to a realization from the density and each column corresponds to a dimension.
The mean vector of dimension k.
The variance-covariance matrix of dimension k times k.
The number of observations to be simulated.
Anders Ellern Bilgrau
dmvnormal functions similarly to dmvnorm from the mvtnorm-package and likewise for rmvnormal and rmvnorm.
dmvnorm
mvtnorm
rmvnorm
dmvnorm and rmvnorm in the mvtnorm-package.
dmvnormal(x = matrix(rnorm(300), 100, 3), mu = 1:3, sigma = diag(3)) rmvnormal(n = 10, mu = 1:4, sigma = diag(4))
Run the code above in your browser using DataLab